(detach-appenders-by-prefix! prefix)Detaches and stops all appenders from the root logger whose name starts with
prefix.
Detaches and stops all appenders from the root logger whose name starts with `prefix`.
(logger-context)Returns the current Logback LoggerContext. Throws when the SLF4J factory is not
a Logback context.
Returns the current Logback `LoggerContext`. Throws when the SLF4J factory is not a Logback context.
(restore-logback! {:keys [root-level root-appenders levels additive]})Restores Logback runtime state from a snapshot previously captured by
snapshot-logback!. Re-attaches root appenders, restores logger levels and
additive flags.
Restores Logback runtime state from a snapshot previously captured by `snapshot-logback!`. Re-attaches root appenders, restores logger levels and additive flags.
(snapshot-logback!)Captures current logback runtime state (safe, no reset):
Captures current logback runtime state (safe, no reset): - root logger level - root appenders (objects) - logger levels map (explicit levels only) - additive flags (optional) Returns a snapshot map.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |